@@ -178,8 +178,9 @@ GMM_STATUS GmmLib::GmmGen12TextureCalc::FillTexCCS(GMM_TEXTURE_INFO *pSurf,
           GMM_IS_64KB_TILE(Surf.Flags) || Surf.Flags.Info.TiledYf) ?
          1 :
          Surf.MSAA.NumSamples) *                                                                                         // MSAA (non-Depth/Stencil) RT samples stored as array planes.
-        ((GMM_IS_64KB_TILE(Surf.Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (Surf.MSAA.NumSamples == 16)) ? 4 : // MSAA x8/x16 stored as pseudo array planes each with 4x samples
-         (GMM_IS_64KB_TILE(Surf.Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (Surf.MSAA.NumSamples == 8)) ? 2 : 1);
+        ((GMM_IS_64KB_TILE(Surf.Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && !pGmmLibContext->GetSkuTable().FtrXe2PlusTiling && (Surf.MSAA.NumSamples == 16)) ? 4 : // MSAA x8/x16 stored as pseudo array planes each with 4x samples
+         (GMM_IS_64KB_TILE(Surf.Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && !pGmmLibContext->GetSkuTable().FtrXe2PlusTiling && (Surf.MSAA.NumSamples == 8)) ? 2 :
+                                                                                                                                                                       1);
 
         if(GMM_IS_64KB_TILE(Surf.Flags) || Surf.Flags.Info.TiledYf)
         {
@@ -246,7 +247,7 @@ GMM_STATUS GmmLib::GmmGen12TextureCalc::FillTexCCS(GMM_TEXTURE_INFO *pSurf,
                 if(Surf.MSAA.NumSamples && !pGmmLibContext->GetSkuTable().FtrTileY)
                 {
                     //MSAA Qpitch is sample-distance, multiply NumSamples in a tile
-                    qPitch *= GFX_MIN(Surf.MSAA.NumSamples, 4);
+                    qPitch *= (pGmmLibContext->GetSkuTable().FtrXe2PlusTiling ? Surf.MSAA.NumSamples : GFX_MIN(Surf.MSAA.NumSamples, 4));
                 }
             }
             else
@@ -271,6 +272,7 @@ GMM_STATUS GmmLib::GmmGen12TextureCalc::FillTexCCS(GMM_TEXTURE_INFO *pSurf,
         //Clear compression request in CCS
         pAuxTexInfo->Flags.Info.RenderCompressed = 0;
         pAuxTexInfo->Flags.Info.MediaCompressed  = 0;
+        pAuxTexInfo->Flags.Info.NotCompressed    = 1;
         pAuxTexInfo->Flags.Info.RedecribedPlanes = 0;
         SetTileMode(pAuxTexInfo);
 
@@ -314,6 +316,11 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
     Height = pTexInfo->BaseHeight;
     Width  = GFX_ULONG_CAST(pTexInfo->BaseWidth);
 
+    if((pTexInfo->Format == GMM_FORMAT_R8G8B8_UINT) && (pTexInfo->Flags.Info.Linear || pTexInfo->Flags.Info.TiledX))
+    {
+        Width += GFX_CEIL_DIV(Width, 63);
+    }
+
     pTexInfo->MSAA.NumSamples = GFX_MAX(pTexInfo->MSAA.NumSamples, 1);
 
     if(pTexInfo->Flags.Info.TiledYf || GMM_IS_64KB_TILE(pTexInfo->Flags))
@@ -328,12 +335,12 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
     ((pTexInfo->Flags.Gpu.Depth || pTexInfo->Flags.Gpu.SeparateStencil ||
       (GMM_IS_64KB_TILE(pTexInfo->Flags) || pTexInfo->Flags.Info.TiledYf)) ? // MSAA Ys/Yf samples are ALSO stored as array planes, calculate size for single sample and expand it later.
      1 :
-     pTexInfo->MSAA.NumSamples) *                                           // MSAA (non-Depth/Stencil) RT samples stored as array planes.
-    ((pTexInfo->Flags.Gpu.Depth || pTexInfo->Flags.Gpu.SeparateStencil) ?   // Depth/Stencil MSAA surface is expanded through Width and Depth
-     1 :    
-    ((GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (pTexInfo->MSAA.NumSamples == 16)) ? 4 : // MSAA x8/x16 stored as pseudo array planes each with 4x samples
-     (GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (pTexInfo->MSAA.NumSamples == 8)) ? 2 : 1));
-
+     pTexInfo->MSAA.NumSamples) *                                                                                              // MSAA (non-Depth/Stencil) RT samples stored as array planes.
+    ((pTexInfo->Flags.Gpu.Depth || pTexInfo->Flags.Gpu.SeparateStencil) ? // Depth/Stencil MSAA surface is expanded through Width and Depth
+     1 :
+     ((GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && !pGmmLibContext->GetSkuTable().FtrXe2PlusTiling && (pTexInfo->MSAA.NumSamples == 16)) ? 4 : // MSAA x8/x16 stored as pseudo array planes each with 4x samples
+      (GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && !pGmmLibContext->GetSkuTable().FtrXe2PlusTiling && (pTexInfo->MSAA.NumSamples == 8)) ? 2 :
+                                                                                                                                                                              1));
     if(GMM_IS_64KB_TILE(pTexInfo->Flags) || pTexInfo->Flags.Info.TiledYf)
     {
         ExpandedArraySize = GFX_CEIL_DIV(ExpandedArraySize, pPlatform->TileInfo[pTexInfo->TileMode].LogicalTileDepth);
@@ -493,6 +500,13 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
     // Align height to even row to avoid hang if HW over-fetch
     BlockHeight = GFX_ALIGN(BlockHeight, __GMM_EVEN_ROW);
 
+    // slice pitch padding to 64KB
+    if (pTexInfo->Flags.Wa.SlicePitchPadding64KB && (ExpandedArraySize > 1))
+    {
+	BlockHeight                = GFX_CEIL_DIV(GFX_ALIGN_NP2(BlockHeight * Pitch, GMM_KBYTE(64)), Pitch);
+        pTexInfo->Alignment.QPitch = BlockHeight;
+    }
+
     if((Status = // <-- Note assignment.
         FillTexPitchAndSize(
         pTexInfo, Pitch, BlockHeight, pRestrictions)) == GMM_SUCCESS)
@@ -1150,6 +1164,55 @@ uint64_t GMM_STDCALL GmmLib::GmmGen12TextureCalc::ScaleFCRectWidth(GMM_TEXTURE_I
     return ScaledWidth;
 }
 
+
+uint64_t GMM_STDCALL GmmLib::GmmGen12TextureCalc::Get2DFCSurfaceWidthFor3DSurface(GMM_TEXTURE_INFO *pTexInfo,
+                                                                                  uint64_t          Width)
+{
+    uint64_t Width2D = Width;
+    if (pTexInfo->Flags.Gpu.CCS)
+    {
+        CCS_UNIT *FCRectAlign = static_cast<PlatformInfoGen12 *>(pGmmLibContext->GetPlatformInfoObj())->GetFCRectAlign();
+        uint8_t   index       = FCMaxModes;
+        if ((index = FCMode(pTexInfo->TileMode, pTexInfo->BitsPerPixel)) < FCMaxModes)
+        {
+            Width2D = GFX_ALIGN(Width2D, FCRectAlign[index].Align.Width);
+            Width2D *= FCRectAlign[index].Downscale.Width;
+        }
+        else
+        {
+            
+            __GMM_ASSERT(0);
+        }
+    }
+    return Width2D;
+}
+uint64_t GMM_STDCALL GmmLib::GmmGen12TextureCalc::Get2DFCSurfaceHeightFor3DSurface(GMM_TEXTURE_INFO *pTexInfo,
+                                                                                   uint32_t          Height,
+                                                                                   uint32_t          Depth)
+{
+    uint64_t Height2D = Height;
+    uint32_t Depth3D  = Depth;
+
+    if (pTexInfo->Flags.Gpu.CCS && (Depth > 1))
+    {
+        CCS_UNIT *FCRectAlign = static_cast<PlatformInfoGen12 *>(pGmmLibContext->GetPlatformInfoObj())->GetFCRectAlign();
+        uint8_t   index       = FCMaxModes;
+        if ((index = FCMode(pTexInfo->TileMode, pTexInfo->BitsPerPixel)) < FCMaxModes)
+        {
+            Height2D = GFX_ALIGN(Height2D, FCRectAlign[index].Align.Height);
+            Height2D *= FCRectAlign[index].Downscale.Height;
+            Depth3D = GFX_ALIGN(Depth3D, FCRectAlign[index].Align.Depth) / FCRectAlign[index].Align.Depth;
+            Height2D *= Depth3D;
+        }
+        else
+        {
+            
+            __GMM_ASSERT(0);
+        }
+    }
+    return Height2D;
+}
+
 /////////////////////////////////////////////////////////////////////////////////////
 /// This function does any special-case conversion from client-provided pseudo creation
 /// parameters to actual parameters for CCS.
